// This code imports various D3 modules and functions.
import {
select,
json,
csv,
geoPath,
geoAlbersUsa,
geoMercator,
scaleOrdinal,
schemeCategory10,
} from 'd3';
import { feature, mesh } from 'topojson';

// This selects the SVG element on the webpage.
const svg = select('svg');

// This sets up the projection and path generator for the map.
const projection = geoMercator()
.translate([-1780, 1050])
.scale([1600]);
const pathGenerator = geoPath().projection(projection);

// This sets up a color scale for the map.
const colorScale = scaleOrdinal(schemeCategory10);

// This fetches the data for the map.
json(
'https://gist.githubusercontent.com/VemulaDowtyasriprasanth/f262dd041bda755a468ef96107011e16/raw/1b45b008dcd08c5a850ca75173b193da0a968436/India.json'
).then((data) => {
// This extracts the country shapes from the data and removes the first feature (which is a point representing the whole country).
const countryShapes = feature(
data,
data.objects.IND_adm1
);
countryShapes.features.shift();

// This adds the country shapes to the SVG and colors them based on their name.
svg
.selectAll('path')
.data(countryShapes.features)
.enter()
.append('path')
.attr('class', 'states')
.attr('fill', (d) => colorScale(d.properties.NAME_1))
.attr('d', (d) => pathGenerator(d))
.append('title')
.text((d) => d.properties.NAME_1);

// This adds labels to the country shapes.
svg
.selectAll('text')
.data(countryShapes.features)
.enter()
.append('text')
.text((d) => d.properties.NAME_1)
.attr('x', d=> pathGenerator.centroid(d)[0] )
.attr('y',d=>pathGenerator.centroid(d)[1])
.attr("text-anchor", "middle")
.attr("font-size", "15px");
});
